@@ -27,7 +27,7 @@ class SystemToGroTop(object):
 
     formats = {
         'atomtypes'    : '{:<7s} {:3d} {:>7.4f}   {:4.1f}   {:3s}     {:14.12f}     {:10.7f}  \n',
-        'atoms'        : '{:6d} {:>10s} {:6d} {:6s} {:6s} {:6d} {:10.3f} {:10.3f} \n',
+        'atoms'        : '{:6d} {:>10s} {:6d} {:6s} {:6s} {:6d} {:11.4f} {:11.4f} \n',
         'bondtypes'    : '{:5s}  {:5s}  {:1d}  {:6.4f}  {:6.1f}\n',
         'bonds'        : '{:3d}  {:3d}   {:1d}\n',
         'pairtypes'    : '{:6s} {:6s}   {:d}    {:14.12f}     {:14.12f}    \n',
@@ -43,6 +43,7 @@ class SystemToGroTop(object):
 
     toptemplate = ""
     toptemplate += "[ atomtypes ]    \n*ATOMTYPES*    \n"
+    toptemplate += "[ nonbond_params ]\n *NONBOND_PARAM* \n"
     toptemplate += "[ pairtypes ]    \n*PAIRTYPES*    \n"
     toptemplate += "[ bondtypes ]    \n*BONDTYPES*    \n"
     toptemplate += "[ angletypes ]   \n*ANGLETYPES*   \n"
@@ -102,6 +103,7 @@ class SystemToGroTop(object):
             _temp_mol.dihedrals += m.dihedrals
             _temp_mol.impropers += m.impropers
             _temp_mol.cmaps    += m.cmaps
+            _temp_mol.pairs    += m.pairs
 
         _temp_mol.forcefield = self.system.molecules[0].forcefield
 
@@ -120,6 +122,7 @@ class SystemToGroTop(object):
         self.lgr.debug("making atom/pair/bond/angle/dihedral/improper types")
         top += self.toptemplate
         top = top.replace('*ATOMTYPES*',     ''.join( self._make_atomtypes(_temp_mol)) )
+        top = top.replace('*NONBOND_PARAM*', ''.join( self._make_nonbond_param(_temp_mol)) )
         top = top.replace('*PAIRTYPES*',     ''.join( self._make_pairtypes(_temp_mol)) )
         top = top.replace('*BONDTYPES*',     ''.join( self._make_bondtypes(_temp_mol)) )
         top = top.replace('*ANGLETYPES*',    ''.join( self._make_angletypes(_temp_mol)))
@@ -200,13 +203,46 @@ class SystemToGroTop(object):
 
         return result
 
+    def _make_nonbond_param(self, m):
+        _added = {}
+        result = []
+        for pr in m.pairs:
+            atom1 = pr.atom1
+            atom4 = pr.atom2
+
+            at1 = atom1.get_atomtype()
+            at4 = atom4.get_atomtype()
+
+            if m.forcefield == 'charmm':
+                if pr.param.coeffs != tuple([]):
+                    print('nonbond_param: found previously provided pair param')
+                    e14 = pr.param.coeffs[0]
+                    l14 = pr.param.coeffs[1]
+                else:
+                    continue
+            else:
+                raise NotImplementedError
+
+            key = [at1,at4]
+            key.sort()
+            key = tuple(key)
+            if key in list(_added.keys()):
+                assert _added[key] == (e14, l14)
+                continue
+
+            _added[key] = (e14, l14)
+            fu = self.functions[m.forcefield]['pairs']
+            line = self.formats['pairtypes'].format(at1, at4, fu, l14, e14)
+            result.append(line)
+
+        return result
 
     def _make_pairtypes(self,m):
         _added = {}
         result = []
-        for dih in m.dihedrals:
-            atom1 = dih.atom1
-            atom4 = dih.atom4
+        for pr in m.pairs:
+            atom1 = pr.atom1
+            atom4 = pr.atom2
 
             at1 = atom1.get_atomtype()
             at4 = atom4.get_atomtype()
@@ -215,6 +251,11 @@ class SystemToGroTop(object):
                 mix_e = lambda x, y: (x*y)**0.5
                 mix_l = lambda x, y: (x+y)* 0.5
 
+                # if pr.param.coeffs != tuple([]):
+                #     print('found previously provided pair param')
+                #     e14 = pr.param.coeffs[0]
+                #     l14 = pr.param.coeffs[1]
+
                 if   hasattr(atom1, 'lje14') and hasattr(atom4, 'ljl14'):
                     e14 = mix_e(atom1.lje14, atom4.lje14)
                     l14 = mix_l(atom1.ljl14, atom4.ljl14)
@@ -418,33 +459,33 @@ class SystemToGroTop(object):
         return result
 
     def _make_pairs(self,m):
-        _bonds = []
-        for bond in m.bonds:
-            _bonds.append((bond.atom1.number, bond.atom2.number))
+        # _bonds = []
+        # for bond in m.bonds:
+        #     _bonds.append((bond.atom1.number, bond.atom2.number))
 
-        _angles = []
-        for ang in m.angles:
-            _angles.append((ang.atom1.number, ang.atom3.number))
+        # _angles = []
+        # for ang in m.angles:
+        #     _angles.append((ang.atom1.number, ang.atom3.number))
 
-        _bonds = set(_bonds)
-        _angles = set(_angles)
+        # _bonds = set(_bonds)
+        # _angles = set(_angles)
 
-        _pairs = []
+        # _pairs = []
 
         result = []
-        for dih in m.dihedrals:
+        for pr in m.pairs:
             fu = self.functions[m.forcefield]['pairs']
-            p1 = dih.atom1.number
-            p4 = dih.atom4.number
+            p1 = pr.atom1.number
+            p4 = pr.atom2.number
 
-            if (p1,p4) in _bonds or (p1,p4) in _angles or \
-               (p4,p1) in _bonds or (p4,p1) in _angles:
-                continue
+            # if (p1,p4) in _bonds or (p1,p4) in _angles or \
+            #    (p4,p1) in _bonds or (p4,p1) in _angles:
+            #     continue
 
-            if (p1,p4) in _pairs or (p4,p1) in _pairs:
-                continue
+            # if (p1,p4) in _pairs or (p4,p1) in _pairs:
+            #     continue
 
-            _pairs.append((p1,p4))
+            # _pairs.append((p1,p4))
 
             line = self.formats['pairs'].format(p1, p4, fu)
             result.append(line)
